diff --git a/qnx_tools_path.mak b/qnx_tools_path.mak
index 7b9f629f..23115a50 100644
--- a/qnx_tools_path.mak
+++ b/qnx_tools_path.mak
@@ -23,6 +23,7 @@ export LINUX_FS_BOOT_PATH ?= $(PSDK_RTOS_PATH)/bootfs
 export VISION_APPS_PATH ?= $(PSDK_RTOS_PATH)/vision_apps
 export SDK_BUILDER_PATH ?= $(PSDK_RTOS_PATH)/sdk_builder
 export PDK_PATH ?= $(PSDK_RTOS_PATH)/pdk
-export GCC_LINUX_ARM_ROOT ?= $(PSDK_TOOLS_PATH)/gcc-arm-9.2-2019.12-x86_64-aarch64-none-linux-gnu
+export GCC_ARCH64_LINUX_VERSION ?= 11.3.rel1
+export GCC_LINUX_ARM_ROOT ?= $(PSDK_TOOLS_PATH)/arm-gnu-toolchain-${GCC_ARCH64_LINUX_VERSION}-x86_64-aarch64-none-linux-gnu
 export ETHFW_PATH ?= $(PSDK_RTOS_PATH)/ethfw
 export TOOLS_INSTALL_PATH=$(PSDK_TOOLS_PATH)
diff --git a/scripts/setup_psdk_additions_j7200.sh b/scripts/setup_psdk_additions_j7200.sh
index f3c57e65..b1d806ab 100755
--- a/scripts/setup_psdk_additions_j7200.sh
+++ b/scripts/setup_psdk_additions_j7200.sh
@@ -16,6 +16,7 @@
 
 ATF_TAG=2fcd408bb3a6756767a43c073c597cef06e7f2d5
 OPTEE_TAG=8e74d47616a20eaa23ca692f4bbbf917a236ed94
+PSDK_TOOLS_PATH=${HOME}/ti
 
 skip_sudo=0
 
@@ -78,32 +79,23 @@ else
     echo ""
 fi
 
-echo "[gcc-arm-9.2-2019.12-x86_64-aarch64-none-elf] Checking ..."
-if [ ! -d gcc-arm-9.2-2019.12-x86_64-aarch64-none-elf ]
-then
-    wget https://developer.arm.com/-/media/Files/downloads/gnu-a/9.2-2019.12/binrel/gcc-arm-9.2-2019.12-x86_64-aarch64-none-elf.tar.xz --no-check-certificate
-    tar xvf gcc-arm-9.2-2019.12-x86_64-aarch64-none-elf.tar.xz > /dev/null
-    rm gcc-arm-9.2-2019.12-x86_64-aarch64-none-elf.tar.xz
-fi
-echo "[gcc-arm-9.2-2019.12-x86_64-aarch64-none-elf] Done"
+GCC_ARCH64_LINUX_VERSION=11.3.rel1
 
-echo "[gcc-arm-9.2-2019.12-x86_64-aarch64-none-linux-gnu] Checking ..."
-if [ ! -d gcc-arm-9.2-2019.12-x86_64-aarch64-none-linux-gnu ]
+# Create ${PSDK_TOOLS_PATH} folder if not present
+if [ ! -d ${PSDK_TOOLS_PATH} ]
 then
-    wget https://developer.arm.com/-/media/Files/downloads/gnu-a/9.2-2019.12/binrel/gcc-arm-9.2-2019.12-x86_64-aarch64-none-linux-gnu.tar.xz --no-check-certificate
-    tar xf gcc-arm-9.2-2019.12-x86_64-aarch64-none-linux-gnu.tar.xz > /dev/null
-    rm gcc-arm-9.2-2019.12-x86_64-aarch64-none-linux-gnu.tar.xz
+    echo "Creating ${PSDK_TOOLS_PATH} folder"
+    mkdir -p ${PSDK_TOOLS_PATH}
 fi
-echo "[gcc-arm-9.2-2019.12-x86_64-aarch64-none-linux-gnu] Done"
 
-echo "[gcc-arm-9.2-2019.12-x86_64-arm-none-linux-gnueabihf] Checking ..."
-if [ ! -d gcc-arm-9.2-2019.12-x86_64-arm-none-linux-gnueabihf ]
+echo "[arm-gnu-toolchain-${GCC_ARCH64_LINUX_VERSION}-x86_64-aarch64-none-linux-gnu] Checking ..."
+if [ ! -d arm-gnu-toolchain-${GCC_ARCH64_LINUX_VERSION}-x86_64-aarch64-none-linux-gnu ]
 then
-    wget https://developer.arm.com/-/media/Files/downloads/gnu-a/9.2-2019.12/binrel/gcc-arm-9.2-2019.12-x86_64-arm-none-linux-gnueabihf.tar.xz --no-check-certificate
-    tar xf gcc-arm-9.2-2019.12-x86_64-arm-none-linux-gnueabihf.tar.xz > /dev/null
-    rm gcc-arm-9.2-2019.12-x86_64-arm-none-linux-gnueabihf.tar.xz
+    wget https://developer.arm.com/-/media/Files/downloads/gnu/${GCC_ARCH64_LINUX_VERSION}/binrel/arm-gnu-toolchain-${GCC_ARCH64_LINUX_VERSION}-x86_64-aarch64-none-linux-gnu.tar.xz -P ${PSDK_TOOLS_PATH} --no-check-certificate
+    tar xf ${PSDK_TOOLS_PATH}/arm-gnu-toolchain-${GCC_ARCH64_LINUX_VERSION}-x86_64-aarch64-none-linux-gnu.tar.xz -C ${PSDK_TOOLS_PATH} > /dev/null
+    rm ${PSDK_TOOLS_PATH}/arm-gnu-toolchain-${GCC_ARCH64_LINUX_VERSION}-x86_64-aarch64-none-linux-gnu.tar.xz
 fi
-echo "[gcc-arm-9.2-2019.12-x86_64-arm-none-linux-gnueabihf] Done"
+echo "[arm-gnu-toolchain-${GCC_ARCH64_LINUX_VERSION}-x86_64-aarch64-none-linux-gnu] Done"
 
 # ATF check
 echo "[ATF] Checking ..."
